@@ -6,21 +6,16 @@ import re
 class ScpArticle(Article):
     """Represents an SCP Article on Wikidot.
 
-    Attributes:
-        page_source (str): The SCP's text.
-        number (int): The SCP's number.
-        branch (scpython.options.Branch): The SCP's original branch.
-        language (scpython.options.Language): The fetched SCP's language.
-        is_joke (boolean): Whether the SCP has a -J flag.
-        full_code (str): The SCP's full code (SCP-XXXX-LANG-J).
+    **Attributes**
+        page_source :class:`str` — The SCP's text.
+        number :class:`int` — The SCP's number.
+        branch :class:`Branch` — The SCP's original branch.
+        language :class:`Language` — The fetched SCP's language.
+        is_joke :class:`boolean` — Whether the SCP has a -J flag.
+        full_code :class:`str` — The SCP's full code (``"SCP-XXXX-LANG-J"``).
     """
 
     def __init__(self, data):
-        """Parses the raw values from the data.
-
-        Args:
-            data (dict): The raw data from Wikidot.
-        """
         super().__init__(data)
 
         self.page_source = data["page_source"]
@@ -31,6 +26,11 @@ class ScpArticle(Article):
         self.branch = data["branch"]
 
     def toJson(self):
+        """Turns the data into a dictionary.
+
+        **Return**
+            json :class:`dict` — A dictionary containing all of the SCP article's data.
+        """
         article = super().toJson()
         return {
             **article,
